@@ -21,7 +21,7 @@
 
 class KnowitApplication : public KUniqueApplication
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
